////////////////////////////////////////////////////////////////////////////////
/////////////////////////// Bandits in the Lab /////////////////////////////////
////////////////////////////////////////////////////////////////////////////////


////////////// var description for "bandits_group-level.dta" ///////////////
// game: 								6 games in total
// n_of_players: 						two and three player groups
// group: 								40 groups in total
// correlation: 						0="control treatment"; 1="strategic treatment"
// pl_exp_time_no_success_intense: 		"experimentation intensity"
// r_dominant_region: 					"experimentation intensity in risky dominant region"
// br_region:  							"experimentation intensity in free-riding region"
// s_dominant_region: 					"experimentation intensity in safe dominant region"
// payoffs: 							"final payoff"
// switches: 							"switches of action"
// inc_switches: 						"incidence of switches"
// single_pioneer: 						"proportion of time with a single pioneer"
// diff_r_br_region: 					"difference in intensities across belief regions"
// first_rs_switch:						"the first switch from risky to safe"
// first_rs_switch_2xstrategic:			"2x calendar time of the first switch in the strategic treatment"
// first_rs_switch_3xstrategic:			"3x calendar time of the first switch in the strategic treatment"
// cutoff_nondiscrete_measure:			"'continuous' measure of cut-off behavior"
// cutoff_nondiscrete_len_measure:		"'more lenient continuous' measure of cut-off behavior"


////////////// var description for "bandits_individual-level.dta" ///////////////
// game: 								6 games in total
// n_of_players: 						two and three player groups
// group: 								40 groups in total
// player:								100 players in total
// correlation: 						0="control treatment"; 1="strategic treatment"
// pl_exp_time_no_success_intense: 		"experimentation intensity"
// r_dominant_region: 					"experimentation intensity in risky dominant region"
// br_region:  							"experimentation intensity in free-riding region"
// payoffs: 							"final payoff"
// switches: 							"switches of action"
// fix_intensity:						"fixation intensity"
// order:								"random order of the games played"
// learning:							"weighted learning function"
// diff_r_br_region: 					"difference in intensities across belief regions"
// cutoff_nondiscrete_measure:			"'continuous' measure of cut-off behavior"


////////////////////////////////////////////////////////////////////////////////
// set current directory to the folder where the code and data are saved
cd " "
use "bandits_group-level.dta", clear


** Section 5.1 Average Experimentation Intensities **
// Table 2: Average Experimentation Intensities
sum pl_exp_time_no_success_intense if n_of_players==2 & correlation==1
sum pl_exp_time_no_success_intense if n_of_players==2 & correlation==0
sum pl_exp_time_no_success_intense if n_of_players==3 & correlation==1
sum pl_exp_time_no_success_intense if n_of_players==3 & correlation==0

ttest pl_exp_time_no_success_intense==0.609 if n_of_players==2 & correlation==1
ttest pl_exp_time_no_success_intense==0.604 if n_of_players==2 & correlation==1
ttest pl_exp_time_no_success_intense==0.517 if n_of_players==3 & correlation==1
ttest pl_exp_time_no_success_intense==0.481 if n_of_players==3 & correlation==1
ttest pl_exp_time_no_success_intense==0.820 if n_of_players==2 & correlation==0
ttest pl_exp_time_no_success_intense==0.853 if n_of_players==3 & correlation==0

ranksum pl_exp_time_no_success_intense if n_of_players==2, by(correlation)
ranksum pl_exp_time_no_success_intense if n_of_players==3, by(correlation)


** Section 5.2 Free-Riding **
// Table 3: Average Experimentation Intensities in Free-Riding Region
sum br_region if n_of_players==2 & correlation==1
sum br_region if n_of_players==2 & correlation==0
sum br_region if n_of_players==3 & correlation==1
sum br_region if n_of_players==3 & correlation==0

ranksum br_region if n_of_players==2, by(correlation)
ranksum br_region if n_of_players==3, by(correlation)

sum r_dominant_region if n_of_players==2 & correlation==1
sum r_dominant_region if n_of_players==2 & correlation==0
sum r_dominant_region if n_of_players==3 & correlation==1
sum r_dominant_region if n_of_players==3 & correlation==0

ranksum r_dominant_region if n_of_players==2, by(correlation)
ranksum r_dominant_region if n_of_players==3, by(correlation)

ranksum diff_r_br_region if n_of_players==2, by(correlation)
ranksum diff_r_br_region if n_of_players==3, by(correlation)

sum s_dominant_region if n_of_players==2 & correlation==1 & game==4
sum s_dominant_region if n_of_players==2 & correlation==0 & game==4
sum s_dominant_region if n_of_players==3 & correlation==1 & game==4
sum s_dominant_region if n_of_players==3 & correlation==0 & game==4
sum s_dominant_region if n_of_players==2 & correlation==1 & game==2
sum s_dominant_region if n_of_players==2 & correlation==0 & game==2
ranksum s_dominant_region if n_of_players==2 & game==2, by(correlation)
ranksum s_dominant_region if n_of_players==2 & game==4, by(correlation)
ranksum s_dominant_region if n_of_players==3 & game==4, by(correlation)


** Section 5.3 Payoffs **
// Table 4: Average Final Payoffs
sum payoffs if n_of_players==2 & correlation==1
sum payoffs if n_of_players==2 & correlation==0
sum payoffs if n_of_players==3 & correlation==1
sum payoffs if n_of_players==3 & correlation==0

ranksum payoffs if n_of_players==2, by(correlation)
ranksum payoffs if n_of_players==3, by(correlation)


** Section 5.4 Cut-Off Behavior **
// Table 5: Average Frequency of Cut-Off Behavior
// for average frequency of cut-off behavior see "individual-level.dta"
sum cutoff_nondiscrete_measure if n_of_players==2 & correlation==1
sum cutoff_nondiscrete_measure if n_of_players==2 & correlation==0
sum cutoff_nondiscrete_measure if n_of_players==3 & correlation==1
sum cutoff_nondiscrete_measure if n_of_players==3 & correlation==0

ranksum cutoff_nondiscrete_measure if n_of_players==2, by(correlation)
ranksum cutoff_nondiscrete_measure if n_of_players==3, by(correlation)

sum cutoff_nondiscrete_len_measure if n_of_players==2 & correlation==1
sum cutoff_nondiscrete_len_measure if n_of_players==2 & correlation==0
sum cutoff_nondiscrete_len_measure if n_of_players==3 & correlation==1
sum cutoff_nondiscrete_len_measure if n_of_players==3 & correlation==0

ranksum cutoff_nondiscrete_len_measure if n_of_players==2, by(correlation)
ranksum cutoff_nondiscrete_len_measure if n_of_players==3, by(correlation)


** Section 5.5 Pioneers **
// Table 6: Proportion of Time with a Single Pioneer
sum single_pioneer if n_of_players==2 & correlation==1
sum single_pioneer if n_of_players==2 & correlation==0
sum single_pioneer if n_of_players==3 & correlation==1
sum single_pioneer if n_of_players==3 & correlation==0

ranksum single_pioneer if n_of_players==2, by(correlation)
ranksum single_pioneer if n_of_players==3, by(correlation)


** Section 6.1 Switches of Action **
// Table 7: Average Number of Switches per Player
sum switches if n_of_players==2 & correlation==1
sum switches if n_of_players==2 & correlation==0
sum switches if n_of_players==3 & correlation==1
sum switches if n_of_players==3 & correlation==0

ranksum switches if n_of_players==2, by(correlation)
ranksum switches if n_of_players==3, by(correlation)

ranksum inc_switches if n_of_players==2, by(correlation)
ranksum inc_switches if n_of_players==3, by(correlation)

ranksum first_rs_switch if n_of_players==2, by(correlation)
ranksum first_rs_switch if n_of_players==3, by(correlation)

sum first_rs_switch_2xstrategic if n_of_players==2 & correlation==1
sum first_rs_switch if n_of_players==2 & correlation==0
sum first_rs_switch_3xstrategic if n_of_players==3 & correlation==1
sum first_rs_switch if n_of_players==3 & correlation==0

ranksum first_rs_switch_2xstrategic, by(correlation)
ranksum first_rs_switch_3xstrategic, by(correlation)


** 6.2 Groups of n = 2 vs. n = 3 **
ranksum single_pioneer if correlation==1, by(n_of_players)
ranksum inc_switches if correlation==1, by(n_of_players)
// for cut-off behavior see "individual-level.dta"
ranksum switches if correlation==1, by(n_of_players)
ranksum switches if correlation==1 & Game<=4, by(n_of_players)


** 6.3 Attention Paid To Partners Experimentation Efforts **
// Table 8: Average Fixation Intensities
sum fix_intense if n_of_players==2 & correlation==1
sum fix_intense if n_of_players==2 & correlation==0
sum fix_intense if n_of_players==3 & correlation==1
sum fix_intense if n_of_players==3 & correlation==0

ranksum fix_intense if n_of_players==2, by(correlation)
ranksum fix_intense if n_of_players==3, by(correlation)


** 6.4 OLS Estimations **
// Table 9: OLS Estimations with Random Effects of Experimentation Intensity, Payoffs, Cut-off Strategy, Switches of Action, and Fixation Intensity
// for regression results see "individual-level.dta"


////////////////////////////////////////////////////////////////////////////////

use "bandits_individual-level.dta", clear

** Section 5.4 Cut-Off Behavior **
// Table 5: Average Frequency of Cut-Off Behavior
sum cutoff if cutoff==1 & n_of_players==2 & correlation==1
sum cutoff if n_of_players==2 & correlation==1
sum cutoff if cutoff==1 & n_of_players==2 & correlation==0
sum cutoff if n_of_players==2 & correlation==0
sum cutoff if cutoff==1 & n_of_players==3 & correlation==1
sum cutoff if n_of_players==3 & correlation==1
sum cutoff if cutoff==1 & n_of_players==3 & correlation==0
sum cutoff if n_of_players==3 & correlation==0

ranksum cutoff if n_of_players==2, by(correlation)
ranksum cutoff if n_of_players==3, by(correlation)

sum cutoff if cutoff==1 & n_of_players==2 & correlation==1 & game<=4
sum cutoff if cutoff==1 & n_of_players==3 & correlation==1 & game<=4


** 6.2 Groups of n = 2 vs. n = 3 **
ranksum cutoff if correlation==1, by(n_of_players)
ranksum cutoff if correlation==1 & game<=4, by(n_of_players)


** 6.4 OLS Estimations **
// Table 9: OLS Estimations with Random Effects of Experimentation Intensity, Payoffs, Cut-off Strategy, Switches of Action, and Fixation Intensity
xtset player game
xtreg pl_exp_time_no_success_intense correlation learning if n_of_players==2, re cluster(group)
xtreg r_dominant_region correlation learning if n_of_players==2, re cluster(group)
xtreg br_region correlation learning if n_of_players==2, re cluster(group)
xtreg payoff correlation learning if n_of_players==2, re cluster(group)
xtreg cutoff correlation learning if n_of_players==2, re cluster(group)
xtreg switches correlation learning if n_of_players==2, re cluster(group)
xtreg fix_intense correlation learning if n_of_players==2, re cluster(group)

xtreg pl_exp_time_no_success_intense correlation learning if n_of_players==3, re cluster(group)
xtreg r_dominant_region correlation learning if n_of_players==3, re cluster(group)
xtreg br_region correlation learning if n_of_players==3, re cluster(group)
xtreg payoff correlation learning if n_of_players==3, re cluster(group)
xtreg cutoff correlation learning if n_of_players==3, re cluster(group)
xtreg switches correlation learning if n_of_players==3, re cluster(group)
xtreg fix_intense correlation learning if n_of_players==3, re cluster(group)
